==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/6f/6fb0724f7cb5040fa05fb6849d472c34.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/UserBundle/Security/SAML/Store/Request/RequestStateStore.php */
class __TwigTemplate_66486b3f0b43062e6cecb188a6375ae2 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\UserBundle\\Security\\SAML\\Store\\Request;

use LightSaml\\State\\Request\\RequestState;
use LightSaml\\Store\\Request\\AbstractRequestStateArrayStore;
use Mautic\\CacheBundle\\Cache\\CacheProviderInterface;

class RequestStateStore extends AbstractRequestStateArrayStore
{
    private string \$prefix;

    public function __construct(private CacheProviderInterface \$cacheProvider, string \$prefix, string \$suffix)
    {
        \$this->prefix = \$prefix.\$suffix;
    }

    public function set(RequestState \$state): self
    {
        \$id = \$state->getId();

        \$item = \$this->cacheProvider->getItem(\$this->prefix.\$id);
        \$item->expiresAfter(2 * 60); // The login is valid for 2 minutes.

        \$item->set(\$state);
        \$this->cacheProvider->save(\$item);

        return \$this;
    }

    public function get(\$id): ?RequestState
    {
        \$item = \$this->cacheProvider->getItem(\$this->prefix.\$id);

        if (!\$item->isHit()) {
            return null;
        }

        \$state = \$item->get();
        if (!\$state instanceof RequestState) {
            return null;
        }

        return \$state;
    }

    public function remove(\$id): bool
    {
        return \$this->cacheProvider->deleteItem(\$this->prefix.\$id);
    }

    public function clear(): void
    {
        \$this->cacheProvider->clear(\$this->prefix);
    }

    /**
     * @return array<mixed>
     */
    protected function getArray(): array
    {
        throw new \\LogicException('Not implemented');
    }

    /**
     * @param array<mixed> \$arr
     */
    protected function setArray(array \$arr): void
    {
        throw new \\LogicException('Not implemented');
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/UserBundle/Security/SAML/Store/Request/RequestStateStore.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/UserBundle/Security/SAML/Store/Request/RequestStateStore.php", "/var/www/mautic-ktn/app/bundles/UserBundle/Security/SAML/Store/Request/RequestStateStore.php");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/6f/6fb0724f7cb5040fa05fb6849d472c34.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/UserBundle/Security/SAML/Store/Request/RequestStateStore.php */
class __TwigTemplate_66486b3f0b43062e6cecb188a6375ae2 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "<?php

declare(strict_types=1);

namespace Mautic\\UserBundle\\Security\\SAML\\Store\\Request;

use LightSaml\\State\\Request\\RequestState;
use LightSaml\\Store\\Request\\AbstractRequestStateArrayStore;
use Mautic\\CacheBundle\\Cache\\CacheProviderInterface;

class RequestStateStore extends AbstractRequestStateArrayStore
{
    private string \$prefix;

    public function __construct(private CacheProviderInterface \$cacheProvider, string \$prefix, string \$suffix)
    {
        \$this->prefix = \$prefix.\$suffix;
    }

    public function set(RequestState \$state): self
    {
        \$id = \$state->getId();

        \$item = \$this->cacheProvider->getItem(\$this->prefix.\$id);
        \$item->expiresAfter(2 * 60); // The login is valid for 2 minutes.

        \$item->set(\$state);
        \$this->cacheProvider->save(\$item);

        return \$this;
    }

    public function get(\$id): ?RequestState
    {
        \$item = \$this->cacheProvider->getItem(\$this->prefix.\$id);

        if (!\$item->isHit()) {
            return null;
        }

        \$state = \$item->get();
        if (!\$state instanceof RequestState) {
            return null;
        }

        return \$state;
    }

    public function remove(\$id): bool
    {
        return \$this->cacheProvider->deleteItem(\$this->prefix.\$id);
    }

    public function clear(): void
    {
        \$this->cacheProvider->clear(\$this->prefix);
    }

    /**
     * @return array<mixed>
     */
    protected function getArray(): array
    {
        throw new \\LogicException('Not implemented');
    }

    /**
     * @param array<mixed> \$arr
     */
    protected function setArray(array \$arr): void
    {
        throw new \\LogicException('Not implemented');
    }
}
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/UserBundle/Security/SAML/Store/Request/RequestStateStore.php";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/UserBundle/Security/SAML/Store/Request/RequestStateStore.php", "/var/www/html/mauticGIT-Test/app/bundles/UserBundle/Security/SAML/Store/Request/RequestStateStore.php");
    }
}
